package com.qmth.cqb.paper.service.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.stereotype.Service;

import cn.com.qmth.examcloud.common.uac.entity.AccessUser;

import com.qmth.cqb.paper.dao.AudioTimeConfigRepo;
import com.qmth.cqb.paper.dao.PaperDetailUnitRepo;
import com.qmth.cqb.paper.dao.PaperRepo;
import com.qmth.cqb.paper.model.AudioTimeConfig;
import com.qmth.cqb.paper.model.Paper;
import com.qmth.cqb.paper.model.PaperDetailUnit;
import com.qmth.cqb.paper.service.AudioTimeConfigService;
import com.qmth.cqb.question.model.Question;

/**
 * @author  	chenken
 * @date    	2017年8月10日 下午3:16:12
 * @company 	QMTH
 * @description 音频次数设置service
 */
@Service("audioTimeConfigService")
public class AudioTimeConfigServiceImpl implements AudioTimeConfigService{

	@Autowired
	private AudioTimeConfigRepo audioTimeConfigRepo;
	
	@Autowired
	private PaperRepo paperRepo;
	
	@Autowired
	private PaperDetailUnitRepo paperDetailUnitRepo;
	
	@Override
	public void saveAudioTimeConfig(List<AudioTimeConfig> audioTimeConfigs,AccessUser user) {
		this.deleteByExamId(audioTimeConfigs.get(0).getExamId());
		
		for(AudioTimeConfig audioTimeConfig:audioTimeConfigs){
			audioTimeConfig.setCreateDate(new Date());
			audioTimeConfig.setCreateUser(user.getName());
		}
		audioTimeConfigRepo.save(audioTimeConfigs);
	}

	@Override
	public List<AudioTimeConfig> findByAudioTimeConfig(AudioTimeConfig audioTimeConfig) {
		return audioTimeConfigRepo.findAll(Example.of(audioTimeConfig));
	}

	@Override
	public void deleteByExamId(String examId) {
		audioTimeConfigRepo.deleteByExamId(examId);
	}

	@Override
	public List<AudioTimeConfig> findAudioTimeConfigList(AudioTimeConfig audioTimeConfig) {
		List<AudioTimeConfig> audioTimeConfigList = new ArrayList<AudioTimeConfig>();
	    Paper paper = paperRepo.findOne(audioTimeConfig.getPaper().getId());
	    //判断是否为音频卷
	    if(paper.getHasAudio()){
	    	//根据试卷查询所有小题
	    	List<PaperDetailUnit> list = paperDetailUnitRepo.findByPaper(paper);
	    	for(PaperDetailUnit paperDetailUnit:list){
	    		if(paperDetailUnit.getQuestion().getHasAudio()){
	    			AudioTimeConfig audioTimeCon = new AudioTimeConfig();
	    			audioTimeCon.setExamId(audioTimeConfig.getExamId());
	    			audioTimeCon.setExamName(audioTimeConfig.getExamName());
	    			audioTimeCon.setGroupCode(audioTimeConfig.getGroupCode());
	    			audioTimeCon.setPaper(paper);
	    			audioTimeCon.setPaperDetailUnit(paperDetailUnit);
	    			audioTimeConfigList.add(audioTimeCon);
	    		}
	    	}
	    	return audioTimeConfigList;
	    }
		return null;
	}

	@Override
	public void addAudioTimeConfig(AudioTimeConfig audioTimeConfig) {
		audioTimeConfig.setCreateDate(new Date());
		audioTimeConfigRepo.save(audioTimeConfig);
	}

}

